#Camera is saved to the file "savedCamera" in this plugin's folder
#Save file is a single line with semi-colon separated values.
#All values are saved as strings.
#Lengths includes unit.
#Remember adding the unit when writing scripts in other programs that outputs a camera.
#This is the order of the values:
#	EyeX
#	EyeY
#	EyeZ
#	TargetX
#	TargetY
#	TargetZ
#	UpX
#	UpY
#	UpZ
#	Aspect ratio
#	Perspective
#	Fov OR Height

module Ene_camMemory

menu = UI.menu("Camera")
menu.add_item("Put To Memory") { self.saveCam }
menu.add_item("Retrieve From Memory") { self.recoverCam }

def self.saveCam
	#Save all parameters to file
	cam = Sketchup.active_model.active_view.camera
	parameters = []
	parameters << cam.eye.x.to_s
	parameters << cam.eye.y.to_s
	parameters << cam.eye.z.to_s
	parameters << cam.target.x.to_s
	parameters << cam.target.y.to_s
	parameters << cam.target.z.to_s
	parameters << cam.up.x.to_s
	parameters << cam.up.y.to_s
	parameters << cam.up.z.to_s
	parameters << cam.aspect_ratio.to_s
	parameters << cam.perspective?
	parameters << cam.fov.to_s if cam.perspective?
	parameters << cam.height.to_s unless cam.perspective?
	parameterString = parameters.join(";")
	path = File.dirname(__FILE__) + "/savedCamera"
	file = File.new(path, "w")
	file.print parameterString
	file.close
end#def

def self.recoverCam
	#Retrieve all camera parameters from file
	path = File.dirname(__FILE__) + "/savedCamera"
	unless File.exists? path then
		UI.messagebox("No saved camera.")
		return
	end#unless
	file = File.open(path)
	parameterString = file.readline.to_s
	file.close
	parameters = parameterString.split(";")
	cam = Sketchup.active_model.active_view.camera
	eye = Geom::Point3d.new(parameters[0].to_l,parameters[1].to_l,parameters[2].to_l)
	target = Geom::Point3d.new(parameters[3].to_l,parameters[4].to_l,parameters[5].to_l)
	up = Geom::Vector3d.new(parameters[6].to_f,parameters[7].to_f,parameters[8].to_f)
	cam.set eye, target, up
	cam.aspect_ratio = parameters[9].to_f
	cam.perspective = parameters[10] == "true"
	cam.fov = parameters[11].to_f if parameters[10] == "true"
	cam.height = parameters[11].to_f unless parameters[10] == "true"
end#def

end#module